@@ -1,8 +1,8 @@
 ##---------------------------------------------------------------------------##
 ##  File:
-##	@(#)  mhtxthtml.pl 2.1 98/03/02 @(#)
+##	@(#) mhtxthtml.pl 2.4 98/10/10 21:42:29
 ##  Author:
-##      Earl Hood       ehood@medusa.acs.uci.edu
+##      Earl Hood       earlhood@usa.net
 ##  Description:
 ##	Library defines routine to filter text/html body parts
 ##	for MHonArc.
@@ -12,7 +12,7 @@
 ##		</MIMEFILTERS>
 ##---------------------------------------------------------------------------##
 ##    MHonArc -- Internet mail-to-HTML converter
-##    Copyright (C) 1995	Earl Hood, ehood@medusa.acs.uci.edu
+##    Copyright (C) 1995-1998	Earl Hood, earlhood@usa.net
 ##
 ##    This program is free software; you can redistribute it and/or modify
 ##    it under the terms of the GNU General Public License as published by
@@ -51,11 +51,23 @@ sub filter {
         $title = "<ADDRESS>Title: <STRONG>$1</STRONG></ADDRESS>\n";
     }
     ## Get/remove BASE url
-    if ($data =~ s%(<base\s[^>]*>)%%i) {
-        $tmp = $1;
-        ($base) = $tmp =~ m%href\s*=\s*['"]([^'"]+)['"]%i;
-        $base =~ s%(.*/).*%$1%;
+    BASEURL: {
+	if ($data =~ s%(<base\s[^>]*>)%%i) {
+	    $tmp = $1;
+	    if ($tmp =~ m|href\s*=\s*['"]([^'"]+)['"]|i) {
+		$base = $1;
+	    } elsif ($tmp =~ m|href\s*=\s*([^\s>]+)|i) {
+		$base = $1;
+	    }
+	    last BASEURL  if ($base =~ /\S/);
+	} 
+	if ((defined($tmp = $fields{'content-base'}) ||
+	     defined($tmp = $fields{'content-location'})) && ($tmp =~ m%/%)) {
+	    ($base = $tmp) =~ s/['"\s]//g;
+	}
     }
+    $base =~ s%(.*/).*%$1%;
+
     ## Strip out certain elements/tags
     $data =~ s%<!doctype\s[^>]*>%%i;
     $data =~ s%</?html[^>]*>%%ig;
@@ -65,28 +77,43 @@ sub filter {
     ## Modify relative urls to absolute using BASE
     if ($base =~ /\S/) {
         $data =~ s%(href\s*=\s*['"])([^'"]+)(['"])%
-		   &addbase($base,$1,$2,$3)%gei;
+		   join("", $1, &addbase($base,$2), $3)%gei;
         $data =~ s%(src\s*=\s*['"])([^'"]+)(['"])%
-                   &addbase($base,$1,$2,$3)%gei;
+		   join("", $1, &addbase($base,$2), $3)%gei;
     }
 
     ($title . $data);
 }
+
 ##---------------------------------------------------------------------------
 sub addbase {
-    local($b, $pre, $u, $suf) = @_;
-    local($ret);
+    my($b, $u) = @_;
+    my($ret);
     $u =~ s/^\s+//;
-    if ($u =~ m%^$Url%o) {	# Non-relative URL, do nothing
-        $ret = $pre . $u . $suf;
-    } else {			# Relative URL
-	if ($u =~ m%^/%) {		# Check for "/..."
-	    $b =~ s%^(${Url}[^/]*)/.*%$1%o;	# Get hostname:port number
+    if ($u =~ m%^$Url%o) {
+	## Non-relative URL, do nothing
+        $ret = $u;
+    } else {
+	## Relative URL
+	if ($u =~ /^\./) {
+	    ## "./---" or "../---": Need to remove and adjust base
+	    ## accordingly.
+	    $b =~ s/\/$//;
+	    my @a = split(/\//, $b);
+	    my $cnt = 0;
+	    while ($u =~ s|^(\.{1,2})/||) { ++$cnt  if length($1) == 2; }
+	    splice(@a, -$cnt)  if $cnt > 0;
+	    $b = join('/', @a, "");
+
+	} elsif ($u =~ m%^/%) {
+	    ## "/---": Just use hostname:port of base.
+	    $b =~ s%^(${Url}[^/]*)/.*%$1%o;
 	}
-        $ret = $pre . $b . $u . $suf;
+        $ret = $b . $u;
     }
     $ret;
 }
+
 ##---------------------------------------------------------------------------
 
 1;
